@@ -1,7 +1,7 @@
 import inspect
 import typing
 
-from di import Dependant
+from di import Dependant, Marker
 from di.api.dependencies import CacheKey, DependantBase
 
 from xpresso.binders.api import (
@@ -16,7 +16,7 @@ from xpresso.binders.api import (
 )
 
 
-class ParameterBinderMarker(Dependant[typing.Any]):
+class ParameterBinderMarker(Marker):
     def __init__(
         self,
         *,
@@ -75,7 +75,7 @@ class BodyBinder(Dependant[typing.Any]):
         self.extractor = extractor
 
 
-class BodyBinderMarker(Dependant[typing.Any]):
+class BodyBinderMarker(Marker):
     def __init__(
         self,
         *,
