@@ -10,6 +10,7 @@ else:
     from typing import Literal
 
 import di
+from di.api.dependencies import DependantBase
 from di.api.providers import DependencyProvider
 
 T = typing.TypeVar("T")
@@ -18,8 +19,7 @@ T = typing.TypeVar("T")
 Scope = Literal["app", "connection", "endpoint"]
 
 
-class Depends(di.Dependant[typing.Any]):
-    __slots__ = ()
+class Depends(di.Marker, di.Dependant[typing.Any]):
     scope: Scope
 
     def __init__(
@@ -38,14 +38,27 @@ class Depends(di.Dependant[typing.Any]):
             sync_to_thread=sync_to_thread,
         )
 
-    def initialize_sub_dependant(self, param: inspect.Parameter) -> Depends:
+    def from_callable(
+        self, call: typing.Optional[DependencyProvider]
+    ) -> DependantBase[typing.Any]:
+        return Depends(
+            call=call,
+            scope=self.scope,
+            use_cache=self.use_cache,
+            wire=self.wire,
+            sync_to_thread=self.sync_to_thread,
+        )
+
+    def initialize_sub_dependant(
+        self, param: inspect.Parameter
+    ) -> DependantBase[typing.Any]:
         if param.default is param.empty:
             # try to auto-wire
             return Depends(
                 call=None,
                 scope=self.scope,
                 use_cache=self.use_cache,
-            )
+            ).register_parameter(param)
         # has a default parameter but we create a dependency anyway just for binds
         # but do not wire it to make autowiring less brittle and less magic
         return Depends(
@@ -53,4 +66,4 @@ class Depends(di.Dependant[typing.Any]):
             scope=self.scope,
             use_cache=self.use_cache,
             wire=False,
-        )
+        ).register_parameter(param)
