@@ -113,7 +113,7 @@ class Schema(FrozenBaseModel):
     oneOf: Optional[List[Schema]] = None
     anyOf: Optional[List[Schema]] = None
     not_: Optional[Schema] = Field(default=None, alias="not")
-    items: Optional[Schema] = None
+    items: Optional[Union[Schema, List[Schema]]] = None
     properties: Optional[Dict[str, Schema]] = None
     additionalProperties: Optional[Union[Schema, Reference, bool]] = None
     description: Optional[str] = None
